summaryrefslogtreecommitdiff
path: root/test
diff options
context:
space:
mode:
authorSean Whitton <spwhitton@spwhitton.name>2026-05-23 16:53:36 +0100
committerSean Whitton <spwhitton@spwhitton.name>2026-05-23 16:53:36 +0100
commitdd42133315b9aea8ed8ce54191a5e85249417a0c (patch)
treed17c7bb225c6f7b6a335c0aa4871bdf8340d2f97 /test
parenteb653865c3a35af115360273fb5147b4943ba2ef (diff)
vc-test--rename-file: Disable part of test for SCCS
* test/lisp/vc/vc-tests/vc-tests.el (vc-test--rename-file): Disable part of test for SCCS.
Diffstat (limited to 'test')
-rw-r--r--test/lisp/vc/vc-tests/vc-tests.el4
1 files changed, 2 insertions, 2 deletions
diff --git a/test/lisp/vc/vc-tests/vc-tests.el b/test/lisp/vc/vc-tests/vc-tests.el
index 1fb17842478..8e2ae2c4454 100644
--- a/test/lisp/vc/vc-tests/vc-tests.el
+++ b/test/lisp/vc/vc-tests/vc-tests.el
@@ -592,8 +592,8 @@ This checks also `vc-backend' and `vc-responsible-backend'."
'added))))
;; Test OK-IF-ALREADY-EXISTS.
- ;; RCS and SRC don't support `vc-delete-file'.
- (unless (memq backend '(RCS SRC))
+ ;; RCS, SRC and SCCS don't support `vc-delete-file'.
+ (unless (memq backend '(RCS SRC SCCS))
(let ((tmp-name (expand-file-name "qux" default-directory))
(new-name (expand-file-name "quuux" default-directory)))
(write-region "qux" nil tmp-name nil 'nomessage)